Index: src/java/org/apache/lucene/index/Payload.java
===================================================================
--- src/java/org/apache/lucene/index/Payload.java	(revision 544711)
+++ src/java/org/apache/lucene/index/Payload.java	(working copy)
@@ -34,12 +34,10 @@
   *  to retrieve the payloads from the index.<br>
   *  <br>
   *  
-  *  <b>
-  *  Warning: The status of the Payloads feature is experimental. The APIs
-  *  introduced here might change in the future and will not be supported anymore
-  *  in such a case. If you want to use this feature in a production environment
-  *  you should wait for an official release.
-  *  </b>
+  * <p><font color="#FF0000">
+  * WARNING: The status of the <b>Payloads</b> feature is experimental. 
+  * The APIs introduced here might change in the future and will not be 
+  * supported anymore in such a case.</font>
   */    
   // TODO: Remove warning after API has been finalized
   public class Payload implements Serializable {
Index: src/java/org/apache/lucene/index/TermPositions.java
===================================================================
--- src/java/org/apache/lucene/index/TermPositions.java	(revision 544711)
+++ src/java/org/apache/lucene/index/TermPositions.java	(working copy)
@@ -44,12 +44,10 @@
      * This is invalid until {@link #nextPosition()} is called for
      * the first time.<br>
      * <br>
-     * <b>
-     * Warning: The status of the Payloads feature is experimental. The APIs
-     * introduced here might change in the future and will not be supported anymore
-     * in such a case. If you want to use this feature in a production environment
-     * you should wait for an official release.
-     * </b> 
+     * <p><font color="#FF0000">
+     * WARNING: The status of the <b>Payloads</b> feature is experimental. 
+     * The APIs introduced here might change in the future and will not be 
+     * supported anymore in such a case.</font>
      * @return length of the current payload in number of bytes
      */
     // TODO: Remove warning after API has been finalized
@@ -64,12 +62,10 @@
      * so if the payload data for the current position is not needed,
      * this method may not be called at all for performance reasons.<br>
      * <br>
-     * <b>
-     * Warning: The status of the Payloads feature is experimental. The APIs
-     * introduced here might change in the future and will not be supported anymore
-     * in such a case. If you want to use this feature in a production environment
-     * you should wait for an official release.
-     * </b>
+     * <p><font color="#FF0000">
+     * WARNING: The status of the <b>Payloads</b> feature is experimental. 
+     * The APIs introduced here might change in the future and will not be 
+     * supported anymore in such a case.</font>
      * 
      * @param data the array into which the data of this payload is to be
      *             stored, if it is big enough; otherwise, a new byte[] array
@@ -88,14 +84,12 @@
    * Payloads can only be loaded once per call to 
    * {@link #nextPosition()}.
    * 
+   * <p><font color="#FF0000">
+   * WARNING: The status of the <b>Payloads</b> feature is experimental. 
+   * The APIs introduced here might change in the future and will not be 
+   * supported anymore in such a case.</font>
+   * 
    * @return true if there is a payload available at this position that can be loaded
-   *
-   * * <b>
-   * Warning: The status of the Payloads feature is experimental. The APIs
-   * introduced here might change in the future and will not be supported anymore
-   * in such a case. If you want to use this feature in a production environment
-   * you should wait for an official release.
-   * </b>
    */
    // TODO: Remove warning after API has been finalized
     public boolean isPayloadAvailable();
Index: src/java/org/apache/lucene/search/payloads/BoostingTermQuery.java
===================================================================
--- src/java/org/apache/lucene/search/payloads/BoostingTermQuery.java	(revision 544711)
+++ src/java/org/apache/lucene/search/payloads/BoostingTermQuery.java	(working copy)
@@ -37,6 +37,10 @@
  * <p>
  * Payload scores are averaged across term occurrences in the document.  
  * 
+ * <p><font color="#FF0000">
+ * WARNING: The status of the <b>Payloads</b> feature is experimental. 
+ * The APIs introduced here might change in the future and will not be 
+ * supported anymore in such a case.</font>
  *
  * @see org.apache.lucene.search.Similarity#scorePayload(byte[], int, int)
  */
Index: src/java/org/apache/lucene/search/payloads/package.html
===================================================================
--- src/java/org/apache/lucene/search/payloads/package.html	(revision 544711)
+++ src/java/org/apache/lucene/search/payloads/package.html	(working copy)
@@ -29,6 +29,13 @@
     <li><a href="./BoostingTermQuery.html">BoostingTermQuery</a> -- Boost a term's score based on the value of the payload located at that term</li>
   </ol>
 </div>
+<DIV>
+<font color="#FF0000">
+WARNING: The status of the <b>Payloads</b> feature is experimental. The APIs
+introduced here might change in the future and will not be supported anymore
+in such a case.
+</font>
+</DIV>
 <DIV>&nbsp;</DIV>
 <DIV align="center">
 </DIV>

Index: src/java/org/apache/lucene/analysis/Token.java
===================================================================
--- src/java/org/apache/lucene/analysis/Token.java	(revision 544711)
+++ src/java/org/apache/lucene/analysis/Token.java	(working copy)
@@ -39,12 +39,10 @@
   {@link TermPositions#getPayload(byte[], int)} to retrieve the payloads from the index.
   
   <br><br>
-  <b>
-  Warning: The status of the Payloads feature is experimental. The APIs
-  introduced here might change in the future and will not be supported anymore
-  in such a case. If you want to use this feature in a production environment
-  you should wait for an official release.
-  </b> 
+  <p><font color="#FF0000">
+  WARNING: The status of the <b>Payloads</b> feature is experimental. 
+  The APIs introduced here might change in the future and will not be 
+  supported anymore in such a case.</font>
 
   @see org.apache.lucene.index.Payload
   */
@@ -137,13 +135,10 @@
 
   /** 
    * Sets this Token's payload.
    * <p>
    * <b>
    * Warning: The status of the Payloads feature is experimental. The APIs
    * introduced here might change in the future and will not be supported anymore
    * in such a case. If you want to use this feature in a production environment
    * you should wait for an official release.
    * </b>  
    */
   // TODO: Remove warning after API has been finalized
   public void setPayload(Payload payload) {
@@ -152,13 +147,10 @@
   
   /** 
    * Returns this Token's payload. 
    * <p>
    * <b>
    * Warning: The status of the Payloads feature is experimental. The APIs
    * introduced here might change in the future and will not be supported anymore
    * in such a case. If you want to use this feature in a production environment
    * you should wait for an official release.
    * </b>   
    */
   // TODO: Remove warning after API has been finalized
   public Payload getPayload() {
@@ -137,13 +135,10 @@
   /** 
    * Sets this Token's payload.
-   * <p>
-   * <b>
-   * Warning: The status of the Payloads feature is experimental. The APIs
-   * introduced here might change in the future and will not be supported anymore
-   * in such a case. If you want to use this feature in a production environment
-   * you should wait for an official release.
-   * </b>  
+   * <p><font color="#FF0000">
+   * WARNING: The status of the <b>Payloads</b> feature is experimental. 
+   * The APIs introduced here might change in the future and will not be 
+   * supported anymore in such a case.</font>
    */
   // TODO: Remove warning after API has been finalized
@@ -152,13 +147,10 @@
   /** 
    * Returns this Token's payload. 
-   * <p>
-   * <b>
-   * Warning: The status of the Payloads feature is experimental. The APIs
-   * introduced here might change in the future and will not be supported anymore
-   * in such a case. If you want to use this feature in a production environment
-   * you should wait for an official release.
-   * </b>   
+   * <p><font color="#FF0000">
+   * WARNING: The status of the <b>Payloads</b> feature is experimental. 
+   * The APIs introduced here might change in the future and will not be 
+   * supported anymore in such a case.</font>
    */
   // TODO: Remove warning after API has been finalized